pub struct ErrorSchema {
pub error: Option<String>,
pub error_description: Option<String>,
pub code: Option<i32>,
pub msg: Option<String>,
pub weak_password: Option<WeakPassword>,
}Expand description
Error response schema.
Fields
error: Option<String>Certain responses will contain this property with the provided values.
Usually one of these:
invalid_requestunauthorized_clientaccess_deniedserver_errortemporarily_unavailableunsupported_otp_type
error_description: Option<String>Certain responses that have an error property may have this property which describes the
error.
code: Option<i32>The HTTP status code. Usually missing if error is present.
msg: Option<String>A basic message describing the problem with the request. Usually missing if error is
present.
weak_password: Option<WeakPassword>Only returned on the /signup endpoint if the password used is too weak. Inspect the
reasons and msg property to identify the causes.
Implementations
Sourceimpl ErrorSchema
impl ErrorSchema
Sourcepub fn builder() -> ErrorSchemaBuilder<((), (), (), (), ())>
pub fn builder() -> ErrorSchemaBuilder<((), (), (), (), ())>
Create a builder for building ErrorSchema.
On the builder, call .error(...)(optional), .error_description(...)(optional), .code(...)(optional), .msg(...)(optional), .weak_password(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of ErrorSchema.