UserSchema

Struct UserSchema 

pub struct UserSchema {
Show 25 fields pub id: Option<String>, pub aud: Option<String>, pub role: Option<String>, pub email: Option<String>, pub email_confirmed_at: Option<DateTime<Utc>>, pub phone: Option<String>, pub phone_confirmed_at: Option<DateTime<Utc>>, pub confirmation_sent_at: Option<DateTime<Utc>>, pub confirmed_at: Option<DateTime<Utc>>, pub recovery_sent_at: Option<DateTime<Utc>>, pub new_email: Option<String>, pub email_change_sent_at: Option<DateTime<Utc>>, pub new_phone: Option<String>, pub phone_change_sent_at: Option<DateTime<Utc>>, pub reauthentication_sent_at: Option<DateTime<Utc>>, pub last_sign_in_at: Option<DateTime<Utc>>, pub app_metadata: Option<OwnedValue>, pub user_metadata: Option<OwnedValue>, pub factors: Option<Vec<MFAFactorSchema>>, pub identities: Option<Vec<IdentitySchema>>, pub banned_until: Option<DateTime<Utc>>, pub created_at: Option<DateTime<Utc>>, pub updated_at: Option<DateTime<Utc>>, pub deleted_at: Option<DateTime<Utc>>, pub is_anonymous: Option<bool>,
}
Object describing the user related to the issued access and refresh tokens.

Fields

id: Option<String>

User ID.

aud: Option<String>

Deprecated.

role: Option<String>

Role.

email: Option<String>

User’s primary contact email.

email_confirmed_at: Option<DateTime<Utc>>

Timestamp when the email was confirmed.

phone: Option<String>

User’s primary contact phone number.

phone_confirmed_at: Option<DateTime<Utc>>

Timestamp when the phone number was confirmed.

confirmation_sent_at: Option<DateTime<Utc>>

Timestamp when the confirmation was sent.

confirmed_at: Option<DateTime<Utc>>

Timestamp when the user was confirmed.

recovery_sent_at: Option<DateTime<Utc>>

Timestamp when the recovery email was sent.

new_email: Option<String>

New email address if the user is changing it.

email_change_sent_at: Option<DateTime<Utc>>

Timestamp when the email change was sent.

new_phone: Option<String>

New phone number if the user is changing it.

phone_change_sent_at: Option<DateTime<Utc>>

Timestamp when the phone change was sent.

reauthentication_sent_at: Option<DateTime<Utc>>

Timestamp when reauthentication was sent.

last_sign_in_at: Option<DateTime<Utc>>

Timestamp of the last sign-in.

app_metadata: Option<OwnedValue>

Application-specific metadata.

user_metadata: Option<OwnedValue>

User-specific metadata.

factors: Option<Vec<MFAFactorSchema>>

Multi-factor authentication factors.

identities: Option<Vec<IdentitySchema>>

External identities linked to the user.

banned_until: Option<DateTime<Utc>>

Timestamp until which the user is banned.

created_at: Option<DateTime<Utc>>

Timestamp when the user was created.

updated_at: Option<DateTime<Utc>>

Timestamp when the user was last updated.

deleted_at: Option<DateTime<Utc>>

Timestamp when the user was deleted.

is_anonymous: Option<bool>

Indicates if the user is anonymous.

Implementations

Source

impl UserSchema

pub fn builder() -> UserSchemaBuilder<((), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), ())>

Create a builder for building UserSchema. On the builder, call .id(...)(optional), .aud(...)(optional), .role(...)(optional), .email(...)(optional), .email_confirmed_at(...)(optional), .phone(...)(optional), .phone_confirmed_at(...)(optional), .confirmation_sent_at(...)(optional), .confirmed_at(...)(optional), .recovery_sent_at(...)(optional), .new_email(...)(optional), .email_change_sent_at(...)(optional), .new_phone(...)(optional), .phone_change_sent_at(...)(optional), .reauthentication_sent_at(...)(optional), .last_sign_in_at(...)(optional), .app_metadata(...)(optional), .user_metadata(...)(optional), .factors(...)(optional), .identities(...)(optional), .banned_until(...)(optional), .created_at(...)(optional), .updated_at(...)(optional), .deleted_at(...)(optional), .is_anonymous(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of UserSchema.